// 2007 Oct. 5 ACM - Problem A
// Written by Christopher Thomas.
//

//
// Includes
//

#include <iostream>
#include <map>
#include <set>

using namespace std;


//
// Macros
//

// Maximum number of cities defined.
// Going for overkill. It's nominally 100.
#define CITYNUMMAX 1000

// Maximum possible capacity.
#define CAPMAX LONG_MAX


//
// Prototypes
//

// Get a hash key for a pair of cities.
// This is an undirected graph, so key(A,B) = key(B,A).
long get_key(long A, long B);

// Get the capacity of the highest-capacity route from city A to city B.
long get_capacity(long A, long B, long citynum, map<long,long> &edges);


//
// Functions
//

// Get a hash key for a pair of cities.
// This is an undirected graph, so key(A,B) = key(B,A).

long get_key(long A, long B)
{
  long key;

  key = (A * CITYNUMMAX) + B;

  return key;
}


// Get the capacity of the highest-capacity route from city A to city B.

long get_capacity(long A, long B, long citynum, map<long,long> &edges)
{
  map<long,long> oldcap, newcap;
  long cidx, oidx;
  long key;
  long thiscap, edgecap;
  bool same;
  long result;

  // Initialize.
  oldcap.clear();
  for (cidx = 1; cidx <= citynum; cidx++)
    oldcap[cidx] = 0;
  oldcap[A] = CAPMAX;

  // Iterate until there's no change between iterations.
  same = true;
  do
  {
// Diagnostics.
#if 0
    cout << "Capacities:\n";
    for (cidx = 1; cidx <= citynum; cidx++)
      cout << "  " << cidx << ":  " << oldcap[cidx] << "\n";
#endif

    // Figure out new capacities based on old ones.
    newcap.clear();
    for (cidx = 1; cidx <= citynum; cidx++)
    {
      newcap[cidx] = oldcap[cidx];

      // Look for better routes.
      for (oidx = 1; oidx <= citynum; oidx++)
      {
        key = get_key(oidx, cidx);
        if (0 < edges.count(key))
        {
          edgecap = edges[key];
          thiscap = oldcap[oidx];
          if (edgecap < thiscap)
            thiscap = edgecap;

          if (thiscap > newcap[cidx])
            newcap[cidx] = thiscap;
        }
      }
    }

    // Copy back to the old map, and check for changes.
    same = true;
    for (cidx = 1; cidx <= citynum; cidx++)
    {
      if (oldcap[cidx] != newcap[cidx])
        same = false;
      oldcap[cidx] = newcap[cidx];
    }
  } while (!same);

  // Extract the result, if any.
  result = 1; // Safe, non-crashing result.
  if (1 > oldcap.count(B))
    cout << "### Target city not in hash!\n";
  else if (1 > oldcap[B])
    cout << "### No route to target city!\n";
  else
    result = oldcap[B];

  return result;
}


//
// Main Program
//

int main(void)
{
  long citynum, edgenum;
  long eidx;
  map<long,long> edges;
  long c1, c2, routecap;
  long start, dest, passengers;
  long capacity;
  long scenidx;
  bool done;
  long result;

  // Initialize.
  scenidx = 1;
  done = false;

  // Process scenarios.
  while (!done)
  {
    cin >> citynum;
    cin >> edgenum;

    if ((1 > citynum) || (1 > edgenum))
      done = true;
    else
    {
      // Build the edge list.

      edges.clear();

      for (eidx = 0; eidx < edgenum; eidx++)
      {
        cin >> c1;
        cin >> c2;
        cin >> routecap;

        // Overwrites duplicates. Shouldn't happen!
        edges[get_key(c1, c2)] = routecap;
      }


      // Get the rest of the problem data.
      cin >> start;
      cin >> dest;
      cin >> passengers;


      // Figure out how many trips are needed.

      capacity = get_capacity(start, dest, citynum, edges);
      // The guide counts as a passenger too.
      capacity--;

      // Handle rounding properly.
      // Do this in a way that handles near-max values gracefully.
      result = passengers / capacity;
      if (0 < (passengers % capacity))
        result++;


      // Report the number of trips.
      cout << "Scenario #" << scenidx << "\n";
      cout << "Minimum Number of Trips = " << result << "\n";
      scenidx++;
    }
  }

  // Report success.
  return 0;
}


//
// This is the end of the file.
//
