// 2007 Oct. 5 ACM - Problem B
// Written by Christopher Thomas.
//

//
// Includes
//

#include <iostream>

using namespace std;


//
// Prototypes
//

// Splits a number into a leading digit and a residue.
void SplitNum(unsigned long long inval,
  unsigned long long &leading, unsigned long long &residue);

// Returns the number of ones present in a "scroll" (complete set of 
// n-digit values, including leading zeroes).
unsigned long long CountScroll(unsigned long long n);

// Returns the number of ones present counting to a "residue" (arbitrary
// number).
unsigned long long CountResidue(unsigned long long r);


//
// Functions
//

// Splits a number into a leading digit and a residue.

void SplitNum(unsigned long long inval,
  unsigned long long &leading, unsigned long long &residue)
{
  unsigned long long modulus;

  // Initialize.
  leading = 0;
  residue = 0;


  // Find the biggest suitable divisor/modulus.
  // This handles zero and single-digit values correctly.
  modulus = 1;
  while ((inval / 10) >= modulus)
    modulus *= 10;

  // Compute leading and residue values.
  // This handles zero and single-digit values correctly.
  leading = inval / modulus;
  residue = inval % modulus;

// Diagnostics.
#if 0
  cout << "Input: " << inval << "  Leading: " << leading
    << "  Residue: " << residue << "\n";
#endif
}


// Returns the number of ones present in a "scroll" (complete set of 
// n-digit values, including leading zeroes).

unsigned long long CountScroll(unsigned long long n)
{
  unsigned long long result;
  unsigned long long nidx;

  // Initialize.
  result = 0;

  // Use the non-recursive formula.
  // This handles zero correctly, so no need to special-case.
  result = n;
  // Multiply by 10^(n-1).
  for (nidx = 1; nidx < n; nidx++)
    result *= 10;

// Diagnostics.
#if 0
  cout << "N: " << n << "  Scroll count: " << result << "\n";
#endif

  return result;
}


// Returns the number of ones present counting to a "residue" (arbitrary
// number).

unsigned long long CountResidue(unsigned long long r)
{
  unsigned long long result;
  unsigned long long leading, residue;
  unsigned long long n, modulus;

  // Initialize.
  result = 0;


  // Special-case zero.
  if (1 > r)
    result = 0;
  else
  {
    // Get the number of digits.
    // This also computes 10^(n-1).
    n = 1;
    modulus = 1;
    while ((r / 10) >= modulus)
    {
      n++;
      modulus *= 10;
    }

    // Get leading and following parts.
    SplitNum(r, leading, residue);


// Diagnostics.
#if 0
    cout << "Value: " << r << "  N: " << n << "  mod: " << modulus
      << "\n";
#endif


    // Use a recursive solution.

    result = 0;

    // Scrolls.
    result += leading * CountScroll(n-1);

    // Residue.
    result += CountResidue(residue);

    // Leading 1.
    if (1 < leading)
      result += modulus;
    else
      result += residue + 1;
  }


// Diagnostics.
#if 0
  cout << "Value: " << r << "  Count: " << result << "\n";
#endif


  return result;
}


//
// Main Program
//

int main(void)
{
  unsigned long long inval, ones;

  do
  {
    cin >> inval;

    if (0 < inval)
    {
      ones = CountResidue(inval);

      if (inval == ones)
        cout << "YES\n";
      else
        cout << "NO\n";
    }
  } while (0 < inval);

  // Report success.
  return 0;
}


//
// This is the end of the file.
//
