// 2007 Oct. 5 ACM - Problem C
// Written by Christopher Thomas.
//

//
// Includes
//

#include <iostream>
#include <map>

using namespace std;


//
// Macros
//

// Maximum input string length.
// Go for overkill; nominal limit is 200.
#define MAXLEN 1024


//
// Prototypes
//

// Reads characters from a stream until newline or EOF is encountered.
// Maximum MAXLEN characters read.
string read_line(istream &instr);


// Finds the common prefix length of two encrypted strings.
long find_plen(string s1, string s2);


//
// Functions
//

// Reads characters from a stream until newline or EOF is encountered.
// Maximum MAXLEN characters read.

string read_line(istream &instr)
{
  char data[MAXLEN];
  string result;

  // Force termination. Shouldn't be needed.
  data[0] = 0;

  // This auto-terminates the string.
  instr.getline(data, MAXLEN);
  // Force it anyways.
  data[MAXLEN-1] = 0;

  // Return the resulting string.
  result = data;
  return result;
}


// Finds the common prefix length of two encrypted strings.

long find_plen(string s1, string s2)
{
  map<char,int> lut1, lut2;
  int next1, next2;
  long len, lidx, lenmax;
  long scratch;
  char thischar;
  int c1, c2;
  bool match;


  // Initialize.

  len = 0;

  lenmax = s1.length();
  scratch = s2.length();
  if (scratch < lenmax)
    lenmax = scratch;

  // Force spaces to correspond to each other.
  lut1[' '] = 0;
  lut2[' '] = 0;
  next1 = 1;
  next2 = 1;


  // Assign indices to input letters in the order they're encountered.

  for (lidx = 0; lidx < lenmax; lidx++)
  {
    thischar = s1[lidx];
    if (1 > lut1.count(thischar))
    {
      lut1[thischar] = next1;
      next1++;
    }

    thischar = s2[lidx];
    if (1 > lut2.count(thischar))
    {
      lut2[thischar] = next2;
      next2++;
    }
  }


// Diagnostics.
#if 0
  cout << "S1: ";
  for (lidx = 0; lidx < lenmax; lidx++)
    cout << " " << lut1[s1[lidx]];
  cout << "\nS2: ";
  for (lidx = 0; lidx < lenmax; lidx++)
    cout << " " << lut2[s2[lidx]];
  cout << "\n";
#endif


  // Go through each string, translating characters to indices.
  // Prefixes will have a matching sequence of indices.

  len = 0;
  match = true;
  while ((len < lenmax) && match)
  {
    // Translate characters.
    // We saw these in the previous scan, so they're in the LUTs.

    thischar = s1[len];
    c1 = lut1[thischar];

    thischar = s2[len];
    c2 = lut2[thischar];


    // Verify match.
    if (c1 != c2)
      match = false;

    // Loop update.
    if (match)
      len++;
  }

  return len;
}


//
// Main Program
//

int main(void)
{
  long paircount, pidx;
  string s1, s2;
  long plen;

  cin >> paircount;

  // Eat the next linefeed.
  s1 = read_line(cin);

  // Scan line pairs.
  for (pidx = 0; pidx < paircount; pidx++)
  {
    s1 = read_line(cin);
    s2 = read_line(cin);

    plen = find_plen(s1, s2);

// Diagnostics.
#if 0
    cout << "S1: \"" << s1 << "\"\n";
    cout << "S2: \"" << s2 << "\"\n";
#endif

    cout << plen << "\n";
  }

  // Report success.
  return 0;
}


//
// This is the end of the file.
//
